@@ -8,7 +8,7 @@ import sys
 from random import randint as random
 from server import Server
 
-__version__ = '0.2.1.8'
+__version__ = '0.2.2.0b'
 __author__ = 'Steven McGrath'
 __email__ = 'steve@chigeek.com'
 
@@ -149,16 +149,19 @@ class BaskitCLI(cmd.Cmd):
             vanilla
             bukkit
             spout
-            canary
         '''
+        if self.server.running():
+            print 'Cannot update while the server is running!'
+            return None
         branch = 'stable'
-        bin_type= None
+        bin_type = None
         cmd_in = s.split()
         if len(cmd_in) > 0:
             branch = cmd_in[0]
         if len(cmd_in) > 1:
             bin_type = cmd_in[1]
         self.server.update(branch, bin_type)
+        self.do_status('')
     
     def do_backup(self, s):
         '''backup
@@ -347,6 +350,7 @@ class Snapshot(cmd.Cmd):
         for filename in os.listdir(self.backup_path):
             print filename[:-4]
 
+
 class WorldCLI(cmd.Cmd):
     prompt = 'baskit_ng [snapshot]>'
     server = None
